/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

import { SDKInitConfig } from "../../shared";

export const reactSDKIntegrationCode = (SDKInitConfig: SDKInitConfig) => {

    return `// The SDK provides a client that can be used to carry out the authentication.
import { IdentityClient } from "@asgardio/oidc-js";

/**
 * Get an SDK Client instance.
 * @type {IdentityClient}
 */
const auth: IdentityClient = IdentityClient.getInstance();

/**
 * The  client can be initialized by passing the relevant parameters such as the server origin, redirect URL, client ID, etc.
 */
const initialize = (): void => {
    auth.initialize({
        signInRedirectURL: "${ SDKInitConfig.signInRedirectURL }",
        signOutRedirectURL: "${ SDKInitConfig.signOutRedirectURL }",
        clientHost: "${ SDKInitConfig.clientHost }",
        clientID: "${ SDKInitConfig.clientID }",
        serverOrigin: "${ SDKInitConfig.serverOrigin }"
    });
};

// The \`sign-in\` hook is used to fire a callback function after signing in is successful.
auth.on(Hooks.SignIn, (response: UserInfo) => {
    alert("You have successfully signed in!");
});

/**
 * Function that handles login.
 */
const handleLogin = (): void => {
    // To sign in, simply call the \`signIn()\` method.
    auth.signIn();
};

/**
 * Function that handles logout.
 */
const handleLogout = (): void => {
    // To sign out, simply call the \`signOut()\` method.
    auth.signOut();
};`;
};

export const javascriptSDKIntegrationCode = (SDKInitConfig: SDKInitConfig) => {

    return `<script>
/**
 * SDK Client instance.
 */
var auth = AsgardioAuth.IdentityClient.getInstance();

/**
 * Initializes the SDK.
 */
function initialize() {
    // Initialize the client with the config object.
    auth.initialize({
        signInRedirectURL: "${ SDKInitConfig.signInRedirectURL }",
        signOutRedirectURL: "${ SDKInitConfig.signOutRedirectURL }",
        clientHost: "${ SDKInitConfig.clientHost }",
        clientID: "${ SDKInitConfig.clientID }",
        serverOrigin: "${ SDKInitConfig.serverOrigin }"
    });
}

//Pass the callback function to be called after signing in using the \`sign-in\` hook
auth.on("sign-in", function (response) {
    alert("You have successfully signed in!");
});

/**
 * Function that handles login.
 */
function handleLogin() {
    // To sign in, simply call the \`signIn()\` method.
    auth.signIn();
}

/**
 * Function that handles logout.
 */
function handleLogout() {
    // To sign out, simply call the \`signOut()\` method.
    auth.signOut();
}
</script>
`;
};

export const angularSDKIntegrationCode = (SDKInitConfig: SDKInitConfig) => {

    return `// The SDK provides a client that can be used to carry out the authentication.
import { IdentityClient } from "@asgardio/oidc-js";

/**
 * Get an SDK Client instance.
 * @type {IdentityClient}
 */
const auth: IdentityClient = IdentityClient.getInstance();

/**
 * The  client can be initialized by passing the relevant parameters such as the server origin, redirect URL, client ID, etc.
 */
const initialize = (): void => {
    auth.initialize({
        signInRedirectURL: "${ SDKInitConfig.signInRedirectURL }",
        signOutRedirectURL: "${ SDKInitConfig.signOutRedirectURL }",
        clientHost: "${ SDKInitConfig.clientHost }",
        clientID: "${ SDKInitConfig.clientID }",
        serverOrigin: "${ SDKInitConfig.serverOrigin }"
    });
};

// The \`sign-in\` hook is used to fire a callback function after signing in is successful.
auth.on(Hooks.SignIn, (response: UserInfo) => {
    alert("You have successfully signed in!");
});

/**
 * Function that handles login.
 */
const handleLogin = (): void => {
    // To sign in, simply call the \`signIn()\` method.
    auth.signIn();
};

/**
 * Function that handles logout.
 */
const handleLogout = (): void => {
    // To sign out, simply call the \`signOut()\` method.
    auth.signOut();
};`;
};
